@@ -19,6 +19,7 @@
 #include "lithosphere.hpp"
 #include "platecapi.hpp"
 #include <stdlib.h>
+#include <stdio.h>
 
 #include <vector>
 
@@ -37,7 +38,6 @@ extern lithosphere* platec_api_get_lithosphere(size_t);
 static std::vector<platec_api_list_elem> lithospheres;
 static size_t last_id = 1;
 
-#include <stdio.h>
 
 void* platec_api_create(long seed, size_t width, size_t height, float sea_level,
                          size_t erosion_period, float folding_ratio,
@@ -76,8 +76,6 @@ const size_t* platec_api_get_agemap(size_t id)
 	return litho->getAgemap();
 }
 
-#include <stdio.h>
-
 float* platec_api_get_heightmap(void *pointer)
 {
 	lithosphere* litho = (lithosphere*)pointer;
@@ -107,13 +105,13 @@ void platec_api_step(void *pointer)
 	litho->update();
 }
 
-// To be called from C
-extern "C" size_t lithosphere_getMapWidth ( void* object)
+
+size_t lithosphere_getMapWidth ( void* object)
 {
     return static_cast<lithosphere*>( object)->getWidth();
 }
 
-extern "C" size_t lithosphere_getMapHeight ( void* object)
+size_t lithosphere_getMapHeight ( void* object)
 {
     return static_cast<lithosphere*>( object)->getHeight();
-}
\ No newline at end of file
+}
