@@ -94,8 +94,32 @@ static PyMethodDef PlatecMethods[] = {
     {NULL, NULL, 0, NULL} /* Sentinel */
 };
 
-PyMODINIT_FUNC
-initplatec(void)
+#if PY_MAJOR_VERSION >= 3
+    static struct PyModuleDef moduledef = {
+        PyModuleDef_HEAD_INIT,
+        "platec",     /* m_name */
+        "Plate tectonics simulation",  /* m_doc */
+        -1,                  /* m_size */
+        PlatecMethods,       /* m_methods */
+        NULL,                /* m_reload */
+        NULL,                /* m_traverse */
+        NULL,                /* m_clear */
+        NULL,                /* m_free */
+    };
+#endif
+
+#if PY_MAJOR_VERSION >= 3
+    #define MOD_INIT(name) PyMODINIT_FUNC PyInit_##name(void)
+#else
+    #define MOD_INIT(name) PyMODINIT_FUNC init##name(void)
+#endif
+
+MOD_INIT(platec)
 {
-    (void) Py_InitModule("platec", PlatecMethods);
+    #if PY_MAJOR_VERSION >= 3
+        return PyModule_Create(&moduledef);
+    #else
+        Py_InitModule3("platec",
+            PlatecMethods, "Plate tectonics simulation");        
+    #endif    
 }
